@@ -1,8 +1,8 @@
+require 'jquery/assert_select' if ::Rails.env.test?
 require 'jquery/rails/engine'
 require 'jquery/rails/version'
 
 module Jquery
   module Rails
-    PROTOTYPE_JS = %w{prototype effects dragdrop controls}
   end
 end
